function [renum]=plotframe2(FEnode,FEelt,FEfix,FEzero,FErigid,nloads,nmass,ndim,plotflags,etype,ecolor,linew)
% VERY USEFUL FOR DEBUGGING. 
% IT WILL HELP YOU SEE YOUR STRUCTURE AS YOU BUILD THE TCL FILE.
% Note: It always plots on the current figure.
% plotflags = [1,1,1,1] will plot node-numbers, element-numbers, loads and
% masses!
%___________________________________________________________________
% For Kavala use: plotframe('\users\divamva\opensees\divamva\RCsect\KavalaBridge.out');
% For G9 use: plotframe('G9Bridge.out');
% for simple2Dframe: plotframe('\users\divamva\opensees\divamva\simple2Dframe\simple2Dframe.out');
% for simple3Dframe: plotframe('\users\divamva\opensees\divamva\simple3Dframe\simple3Dframe.out');
% Updated: 19/07/04, made compatible with 2D structures as well
% Updated: 2/10/04, added the ability to plot node and element numbers
%                   it also checks now if FEnode is empty to stop execution.
% Updated: 15/02/05: changed clf to cla so that it will not clear the whole 
%                    figure window, only the current axes. This is useful when
%                    working with "idpost". It clears the GUI otherwise!
% Updated: 19/02/05: Vastly improved the speed of node renumbering. Instead
%                    of a loop it is now a single command!
% Updated: 19/04/05: Fixed a problem when plotting element numbers and 
%                    FEzero was empty. Now when empty, no errors happen.
%                    Also if nodeplot is on, then ndim==2 cases create no
%                    problems!
% Updated: 26/04/05: Added plotflags and nloads,nmass plotting capability.
% Updated: 28/11/06: Fixed a problem when node 0 exists in a model. For
%                    this reason, renum entries are shifted by 1! 
% Updated: 22/06/07: Regarding the above fix, it was implemented
%                    erroneously for 2D structures. Now it is fine!
% Updated  05/09/08: Added the linew input to control linewidth when
%                    plotting elements
% Updated 07/Mar/10: Fixed capability to plot linear and quad elements 
%                    (added sometime in the 2009 summer) by initializing e4.  
% Updated 16/May/17: Added coloring to each element type via the new variables 
%                    etype and ecolor 
%

axisfontsize=12;
numfontsize=8;
if nargin==0, error('need at least FEnode input'); end
if nargin<12, linew=0.5; end
if nargin<11, ecolor={[0,0,1],[0,1,0],[1,0,0],[1,0,1],[0,1,1],[1,1,0]}; end
if nargin<10, etype={}; end
if nargin<9 
   plotflags=[0,0,0,0]; 
end
nodeplot=plotflags(1);
eleplot=plotflags(2);
loadplot=plotflags(3);
massplot=plotflags(4);

if nargin<8, ndim=size(FEnode,2)-1; end 
if nargin<7, nmass=[]; end
if nargin<6, nloads=[]; end
if nargin<5, FErigid=[]; end
if nargin<4, FEzero=[]; end
if nargin<3 FEfix=[]; end
if nargin<2 FEelt=[]; end
e4=[];   

%keyboard
cla;hold on
set(gca,'fontsize',axisfontsize)
if ndim==2
   plot(FEnode(:,2),FEnode(:,3),'k.')
else
   plot3(FEnode(:,2),FEnode(:,3),FEnode(:,4),'k.')
end

% renumbering of nodes : OLD version, SLOW!
%Nr=1:max(FEnode(:,1));
%for i=1:length(Nr)
%  tr=find(FEnode(:,1)==Nr(i));
%  if isempty(tr) renum(i)=NaN; else renum(i)=tr; end
%end

% renumbering of nodes : NEW version, FAST!
%renum=zeros(1,max(FEnode(:,1)));
%for i=1:size(FEnode,1)
%   renum(FEnode(i,1))=i;
%end

% renumbering of nodes : NEWER version, EVEN FASTER!
% Note: Since opensees allows the existence of node 0, I have shifted
% all node numbers by 1, to allow for such a problem. So all the node
% references channeled through renum must also be increased by 1.
renum=zeros(1,max(FEnode(:,1)));
renum(FEnode(:,1)+1)=[1:size(FEnode,1)];


if ~isempty(FEelt)
   % Good for 2-node elements
   if size(FEelt,2)==3
      % only 2node elements exist
      e2=1:size(FEelt,1);
   else
      % up to the last index that has a NaN value for 3rd node!
      % you may see a warning here!
      e2=1:find(isnan(FEelt(:,4)),1,'last');
   end
   
   
   if ~isempty(e2)
      if ndim==2
         if isempty(etype)
            plot([FEnode(renum(FEelt(e2,2)+1),2),FEnode(renum(FEelt(e2,3)+1),2)]',...
                 [FEnode(renum(FEelt(e2,2)+1),3),FEnode(renum(FEelt(e2,3)+1),3)]',...
                 'b-','linew',linew)
         else
            % we were asked to do separate colors for each element type
            [eltypes,~,iel]=unique(etype);
            for i=1:length(eltypes)
               e2i=e2(iel==i);
               plot([FEnode(renum(FEelt(e2i,2)+1),2),FEnode(renum(FEelt(e2i,3)+1),2)]',...
                    [FEnode(renum(FEelt(e2i,2)+1),3),FEnode(renum(FEelt(e2i,3)+1),3)]',...
                    '-','color',ecolor{mod(i-1,length(ecolor))+1},'linew',linew);
            end
         end
      else
         if isempty(etype)
            plot3([FEnode(renum(FEelt(e2,2)+1),2),FEnode(renum(FEelt(e2,3)+1),2)]',...
               [FEnode(renum(FEelt(e2,2)+1),3),FEnode(renum(FEelt(e2,3)+1),3)]',...
               [FEnode(renum(FEelt(e2,2)+1),4),FEnode(renum(FEelt(e2,3)+1),4)]',...
               'b-','linew',linew)
         else
            % we were asked to do separate colors for each element type
            [eltypes,~,iel]=unique(etype);
            for i=1:length(eltypes)
               e2i=e2(iel==i);
               warning('line below has not be tested yet in 3D, be careful')
               plot3([FEnode(renum(FEelt(e2i,2)+1),2),FEnode(renum(FEelt(e2i,3)+1),2)]',...
                     [FEnode(renum(FEelt(e2i,2)+1),3),FEnode(renum(FEelt(e2i,3)+1),3)]',...
                     [FEnode(renum(FEelt(e2i,2)+1),4),FEnode(renum(FEelt(e2i,3)+1),4)]',...
                     '-','color',ecolor{mod(i-1,length(ecolor))+1},'linew',linew);
            end
         end
      end
   end
   
   
   % Good for Quads. Must fix this when bricks are also used!
   if size(FEelt,2)>=5
      % 4node elements exist
      % Go up to the last index that has a non-NaN value for 3rd node!
      ie2=max([e2+1,1]); % works for empty e2.
      e4=ie2:size(FEelt,1);
   end
   if ~isempty(e4)
      if ndim==2
         patch([FEnode(renum(FEelt(e4,2)+1),2),FEnode(renum(FEelt(e4,3)+1),2),FEnode(renum(FEelt(e4,4)+1),2),FEnode(renum(FEelt(e4,5)+1),2)]',...
               [FEnode(renum(FEelt(e4,2)+1),3),FEnode(renum(FEelt(e4,3)+1),3),FEnode(renum(FEelt(e4,4)+1),3),FEnode(renum(FEelt(e4,5)+1),3)]',[0.6,0.6,1],'linew',linew)
      else
         patch([FEnode(renum(FEelt(e4,2)+1),2),FEnode(renum(FEelt(e4,3)+1),2),FEnode(renum(FEelt(e4,4)+1),2),FEnode(renum(FEelt(e4,5)+1),2)]',...
               [FEnode(renum(FEelt(e4,2)+1),3),FEnode(renum(FEelt(e4,3)+1),3),FEnode(renum(FEelt(e4,4)+1),3),FEnode(renum(FEelt(e4,5)+1),3)]',...
               [FEnode(renum(FEelt(e4,2)+1),4),FEnode(renum(FEelt(e4,3)+1),4),FEnode(renum(FEelt(e4,4)+1),4),FEnode(renum(FEelt(e4,5)+1),4)]',...
               [0,0,0.5],'linew',linew)
      end
   end
end

if ~isempty(FEfix)  
   if ndim==2
      plot(FEnode(renum(FEfix(:,1)+1),2),FEnode(renum(FEfix(:,1)+1),3),'rs')      
   else
      plot3(FEnode(renum(FEfix(:,1)+1),2),FEnode(renum(FEfix(:,1)+1),3),...
         FEnode(renum(FEfix(:,1)+1),4),'rs')
   end
end

if ~isempty(FEzero)
   if ndim==2
      plot(FEnode(renum(FEzero(:,2)+1),2),FEnode(renum(FEzero(:,2)+1),3),'go')
   else
      plot3(FEnode(renum(FEzero(:,2)+1),2),FEnode(renum(FEzero(:,2)+1),3),...
        FEnode(renum(FEzero(:,2)+1),4),'go')
  end
end

if ~isempty(FErigid)
   if ndim==2
      plot([FEnode(renum(FErigid(:,1)+1),2),FEnode(renum(FErigid(:,2)+1),2)]',...
         [FEnode(renum(FErigid(:,1)+1),3),FEnode(renum(FErigid(:,2)+1),3)]','k-')
   else
      plot3([FEnode(renum(FErigid(:,1)+1),2),FEnode(renum(FErigid(:,2)+1),2)]',...
         [FEnode(renum(FErigid(:,1)+1),3),FEnode(renum(FErigid(:,2)+1),3)]',...
         [FEnode(renum(FErigid(:,1)+1),4),FEnode(renum(FErigid(:,2)+1),4)]','k-')
   end
end

% these parts were taken and modified from draw3d.m supplied by 
% Paul Lam <paullam@ust.hk>
% ADD ELEMENT NUMBERS TO THE PLOT!
%Rx=max(FEnode(:,2))-min(FEnode(:,2));
%Ry=max(FEnode(:,3))-min(FEnode(:,3));
%if ndim==3
%   Rz=max(FEnode(:,4))-min(FEnode(:,4));
%end
%dx=Rx/400; dy=Ry/400; dz=Rz/400;
dx=0;dy=0;dz=0;

if eleplot && ~isempty(FEelt)
   % regular elements
   fx=[FEnode(renum(FEelt(:,2)+1),2),FEnode(renum(FEelt(:,3)+1),2)]';
   fy=[FEnode(renum(FEelt(:,2)+1),3),FEnode(renum(FEelt(:,3)+1),3)]';
   if ndim==2
      text(sum(fx)/2+dx,sum(fy)/2+dy,num2str(FEelt(:,1)),...
         'Color','b','fontsize',numfontsize,...
         'horizontalalignment','right','verticalalignment','bottom');
   else
      fz=[FEnode(renum(FEelt(:,2)+1),4),FEnode(renum(FEelt(:,3)+1),4)]';
      text(sum(fx)/2+dx,sum(fy)/2+dy,sum(fz/2)+dz,num2str(FEelt(:,1)),...
         'Color','b','fontsize',numfontsize,...
         'horizontalalignment','right','verticalalignment','bottom');
   end
   if ~isempty(FEzero)
      % zerolength elements
      fx=FEnode(renum(FEzero(:,2)+1),2)';
      fy=FEnode(renum(FEzero(:,2)+1),3)';
      if ndim==2
         text(fx+dx,fy+dy,num2str(FEzero(:,1)),...
            'Color','r','fontsize',numfontsize,...
            'horizontalalignment','right','verticalalignment','bottom');
      else
         fz=FEnode(renum(FEzero(:,2)+1),4)';
         text(fx+dx,fy+dy,fz+dz,num2str(FEzero(:,1)),...
            'Color','r','fontsize',numfontsize,...
            'horizontalalignment','right','verticalalignment','bottom');
      end
   end
end


if nodeplot
   % Find a way to detect coincident nodes and plot them together
   % as "4,5,6" for example.
   if ndim==2
      text(FEnode(:,2),FEnode(:,3),num2str(FEnode(:,1)),...
      'Color','k','fontsize',numfontsize,...
      'horizontalalignment','left','verticalalignment','top');
   else
      text(FEnode(:,2),FEnode(:,3),FEnode(:,4),num2str(FEnode(:,1)),...
         'Color','k','fontsize',numfontsize,...
         'horizontalalignment','left','verticalalignment','top');
   end
end
   
if loadplot && ~isempty(nloads)
   
   %plot_framesensors(FEloads,FEnode,ndim,'r',0);
   % based on the above file create a plot_loadmass(FEnode,nloads,ndim,'r',..)
end


% set equal axis, default 3D view

xlabel('x-axis'); ylabel('y-axis'); zlabel('z-axis');
axis equal
axis tight
if ndim==3, view(3); end

% LEGEND: BLUE DOT: Node, 
%         RED SQUARE: FIX (any kind)
%         Green CIRCLE: Zerolength element (any kind)
%         Blue line: element
%         Black line: rigid element