function plot_cv_IDAs(svalues,dvalues,cv,lowest_C,xlim,Hfig,linestyles,...
                      pointstyles,labelflag,flatline,linew)
%                   
%---------------------------------------------
% plots the interpolated IDAs
%
%____________________________________________________
%
% Updated Feb 21, 2005: Fixed the linestyle, pointstyle assignment scheme.
%                       Now it is perfect so that the first IDA always 
%                       gets the first linestyle & pointstyle!
% Copyright (c) 1999 by D.Vamvatsikos

if nargin<11, linew=1; end
if nargin<10, flatline=0; end
if nargin<9, labelflag=1; end
if nargin<8, pointstyles={'k.'}; end
if nargin<7 || isempty(linestyles)
   % default line styles to use for plotting
   linestyles={'m-','r-','g-','b-','k-','m--','r--','g--','b--','k--'};
end
if nargin<6, Hfig=1; end
if nargin<5, xlim=[]; end

figure(Hfig); clf; hold on

% determine the dvalue up to which the flatline will be drawn.
% make it to be 10% higher than the maximum dvalue present, or 
if flatline
   maxdv=0;
   for i=1:length(cv)
      maxdv=max([maxdv,dvalues{i}(lowest_C(i))]);
   end
   if ~isempty(xlim)
      flatlinefin=max(1.1*maxdv,xlim(2)); 
   else
      flatlinefin=1.1*maxdv;
   end
end

for i=1:length(cv)
   fnplt(cv{i},linestyles{mod(i-1,length(linestyles))+1},linew)
   if flatline
      plot([dvalues{i}(lowest_C(i)),flatlinefin],...
            repmat(svalues{i}(lowest_C(i)),1,2),...
            linestyles{mod(i-1,length(linestyles))+1},'linew',linew)
      % put a serial number at the end   
      if labelflag
         text(flatlinefin,svalues{i}(lowest_C(i)),sprintf('\\bf %d',i))
      end
   else
      % put a serial number at the end
      if labelflag
         text(dvalues{i}(lowest_C(i)),svalues{i}(lowest_C(i)),sprintf('\\bf %d',i))
      end
   end
   % use this to see individual points from the actual runs
   if ~isempty(pointstyles)
      plot(dvalues{i}(1:lowest_C(i)),svalues{i}(1:lowest_C(i)),...
         pointstyles{mod(i-1,length(pointstyles))+1})
   end
end
% set x-axis limits.
if ~isempty(xlim)
   set(gca,'xlim',xlim)
end
set(gca,'box','on')