function [h]=plot_qSa_fractile_IDAs(dr_range,qSa,xlim,qs,Hfig,linestyles,...
                                             labelflag,flatline,linew)
%---------------------------------------------
% plot 16,50,84% fractiles given levels of drift (or any EDP)
%
% qSa  : contains the actual fractile drvalues. Each column corresponds to
%        one value of "qs" and each row to one value of dr_range.
% qs   : Contains the NAMES of the fractiles (e.g. 0.16). 
%        NOTE THAT THE FRACTILES ARE NOT COMPUTED ACCORDING TO qs. So if
%        you provide say qdr containing fractiles 16,50,84 and you provide
%        the qs=0.50, it will only plot the 1st column of qdr (the 16% fractile) 
%        and label it as 50%!!! BE VERY CAREFUL HERE
% labelflag: if 0, no labels are created
%            if 1 (default), then labels are set at the end of the curve,
%            if 2, then the labels go direcly beneath the curve, at its end.
% flatline : if non-zero then an explicit flatline is drawn.
% linestyles,linew : see plot_cv_IDAs
%
% Created, 12/May/2008, Copyright (c) 2008 by D.Vamvatsikos
%          Based on plot_qdr_fractile_IDAs.m
%
%

if nargin<9, linew=2; end
if nargin<8, flatline=0; end
if nargin<7, labelflag=1; end
if nargin<6 || isempty(linestyles)
   % default line styles to use for plotting
   linestyles={{'m--'},{'b-'},{'r-.'}};
end
if nargin<5||isempty(Hfig), Hfig=1; end
if nargin<4, qs=[0.16,0.50,0.84]'; end
if nargin<3, xlim=[]; end 


% qSa will contain the same Sa when flatline is reached. Determine the
% index of the 1st appearance of that value for each fractile.
cap_qSa=max(qSa');
for i=1:size(qSa,1)
   maxdvi(i)=min(find(qSa(i,:)==cap_qSa(i)));
end

% determine the dvalue up to which the flatline will be drawn.
% make it to be 10% higher than the maximum dvalue present, or 
% equal to xlim, the externally supplied x-axis limit
if flatline
   if ~isempty(xlim)
      %flatlinefin=max(1.1*maxdv,xlim(2)); 
      flatlinefin=xlim(2);
   else
      maxdv=dr_range(max(maxdvi));
      flatlinefin=1.1*maxdv;
   end
end

if labelflag==2
   labelopt={'HorizontalAlignment','right','VerticalAlignment','Top'};
else
   labelopt={};
end

figure(Hfig); hold on
for i=1:length(qs)
   indy=1:maxdvi(i);
   % Note that qSa may already contain the flatline feature due to its
   % creation by simple_processIDA. It is better to remove and redraw it
   % so as to keep consistent with the flatline-switch and also use only
   % two points instead of 50 for the straight flatline!
   h(i)=plot(dr_range(indy),qSa(i,indy),linestyles{mod(i-1,length(linestyles))+1}{:},...
          'linewidth',linew);
   mindy=maxdvi(i);    
   if flatline
      plot([dr_range(mindy),flatlinefin],...
            repmat(qSa(i,mindy),1,2),...
            linestyles{mod(i-1,length(linestyles))+1}{:},'linew',linew)
      % put the fractile percentage designator at the end of the curve   
      if labelflag
         text(flatlinefin,qSa(i,mindy),sprintf('\\bf %2d%%',round(qs(i)*100)),labelopt{:})
      end
   else
      if labelflag
         text(dr_range(mindy),qSa(i,mindy),sprintf('\\bf %2d%%',round(qs(i)*100)),labelopt{:})
      end
   end
end

if ~isempty(xlim)
   set(gca,'xlim',xlim)
end
set(gca,'box','on')