function icscvn(svalues,dvalues)
%CSCVN 'Natural' or periodic cubic spline curve.
%
%   CS  = CSCVN(POINTS) 
% 
%   returns a parametric 'natural' cubic spline which interpolates to
%   the given points POINTS(:,i)  at parameter values  t(i) ,
%   i=1,2,..., with  t(i)  chosen by Eugene Lee''s centripetal scheme,
%   i.e., as accumulated squareroot of chord-length. 
%-------------------------------------------------------------
% This Function checks the validity of several error measures
% for spline interpolations. It also tests the superiority of
% using same scale (x,y) input to fit through cscvn.m method!!

% (Last updated: September 3rd, 1999)
% Copyright (c) 1999 by D.Vamvatsikos

%R=22;
%// if dvalues,svalues have no initial zero, correct this please!

for R=1:length(svalues)
  scalefactor=svalues{R}(end)/max(dvalues{R})
  %xy=[[0,dvalues{R}];[0,svalues{R}]];
  % scale initially the x,y points to the same scale, makes
  % interpolation better!!
  xy=[dvalues{R}*scalefactor,svalues{R}]'; %//'


  cv=cscvn(xy);

  [breaks,coefs]=ppbrk(cv);
  coefs(1:2:size(coefs,1),:)=1/scalefactor*coefs(1:2:size(coefs,1),:);
  cv2=ppmak(breaks,coefs,2);
 
  xy2=[dvalues{R},svalues{R}]'; %//'
 
  cv_old=cscvn(xy2);
  %// obviously "csape" is not influenced by scaling!     
  cv_old2=csape(svalues{R},dvalues{R}*scalefactor,'variational');
  xy3=fnplt(cv_old2); xy3=flipud(xy3); %// flip rows to plot drift as x.

  figure(1);clf; 
  fnplt(cv2,'r-'); hold on; plot(xy2(1,:),xy2(2,:),'bo--');
  fnplt(cv_old,'k-');
  %//plot(xy3(1,:)/scalefactor,xy3(2,:),'g--') %//'
  figure(2);clf;
  clear sumx sumy diffx diffy negx negy singlevalue

  %// compute error on transformed spline, as it allows better to add x,y error
  for i=1:(length(breaks)-1)
     tt=breaks(i):(breaks(i+1)-breaks(i))/20:breaks(i+1);
     xy=ppual(cv,tt);   
     figure(2)
     subplot(2,1,1)
     plot(tt,xy(1,:),'b-')  
     hold on
     l=tt(end)-tt(1);
     x=xy(1,1)+(tt-tt(1))*(xy(1,end)-xy(1,1))/l;
     plot(tt,x)
     ylabel('x(t) fit vs straight line interpolation')    

     subplot(2,1,2)
     plot(tt,xy(2,:))
     y=xy(2,1)+(tt-tt(1))*(xy(2,end)-xy(2,1))/l;
     hold on
     plot(tt,y)  
     ylabel('y(t) fit vs straight line interpolation') 
     xlabel('cumulative sqrt of arclength : parameter t')
     %pause
     %// maybe we would want to promote "closeness" to the straight line 
     %// in any sense, not just in absolute, so if curve criss-crosses?
     %// but if it criss-crosses badly? (large peaks on both sides)?
     %// No leave it absolute. Anyway if curve crosses straight line 
     %// (like in dimitrios.mat, R=21 curve) that is beneficial
     %// as it  
     sumx(i)=trapz(tt,abs(x-xy(1,:)));
     sumy(i)=trapz(tt,abs(y-xy(2,:)));
     diffx(i)=max(abs(x-xy(1,:)));
     diffy(i)=max(abs(y-xy(2,:)));
     %// check fit for negative drifts 
     negx(i)=any(xy(1,:)<0);
     %// useless check for negative Sas. Never occurs! 
     negy(i)=any(xy(2,:)<0);
     %// check  if Sa is increasing (i.e. single 
     %// the most important thing to repair is negative drifts
     %// and then non-single valued function.
     %sum(diff(xy(2,:))<0)
     %keyboard
     singlevalue(i)=sum(diff(xy(2,:))<0);
  end

  err=sqrt(sumx.^2+sumy.^2)  
  maxerr=(diff(breaks).^2)
  threshold=0.10  %// a threshold of 0.10 - 0.20 seems reasonable.
                  %// we are comparing how much 
  [err;maxerr;err./maxerr;err./maxerr<threshold]
  % another criterion: maximum "distance" not more than some 
  % fraction of the arclength.
  err2=sqrt(diffx.^2+diffy.^2);
  maxerr2=diff(breaks);
  threshold2=0.15;    %// strangely not lower than "threshold": 0.1 - 0.2 
  [err2;maxerr2;err2./maxerr2;err2./maxerr2<threshold2]
  [negx;negy;singlevalue]
  
  %// the most important thing to repair is negative drifts
  figure(1);
  % it seems to me that criterion #2 better allows us to distinguish.
  % anyway a very large distance is what we are looking for
  % // careful the "distances" aren't perpendicular to the straight line.
  %// they are defined in a whole new space !!
  pause
end
